==> lire_1.5.orig.tar.gz: lire-1.5/dialup/po/lire-dialup.pot.pl <==
# REFERENCE: dialup.cfg
__( q{Connections} );
# REFERENCE: dialup.cfg
__( q{Duration} );
# REFERENCE: dialup.cfg
__( q{Telephone Number} );
# REFERENCE: dialup.cfg
__( q{Costs} );
# REFERENCE: schema:dialup
__( q{DLF Schema for Dialup service} );
# REFERENCE: schema:dialup
__( q{The <type>dialup</type> DLF schema represents each connection
   attempt with one DLF record.
  } );
# REFERENCE: schema:dialup
__( q{Timestamp} );
# REFERENCE: schema:dialup
__( q{The time at which the dial up connection started.} );
# REFERENCE: schema:dialup
__( q{Local Number} );
# REFERENCE: schema:dialup
__( q{Telephone number of the local telephone.} );
# REFERENCE: schema:dialup
__( q{Remote Number} );
# REFERENCE: schema:dialup
__( q{Telephone number which is being called.} );
# REFERENCE: schema:dialup
__( q{connection_time} );
# REFERENCE: schema:dialup
__( q{The duration of the dial up connection.} );
# REFERENCE: schema:dialup
__( q{Direction} );
# REFERENCE: schema:dialup
__( q{Direction of the connection. <literal>Inbound</literal>
         connections are those in which is machine on which the log is
         recorded is called, while in <literal>outbound</literal>
         connections the machine makes the call.
   } );
# REFERENCE: schema:dialup
__( q{Connection Type} );
# REFERENCE: schema:dialup
__( q{The type of the connection: <literal>speech</literal>
         or <literal>data</literal>.} );
# REFERENCE: schema:dialup
__( q{Connect Status} );
# REFERENCE: schema:dialup
__( q{The status of the connection: 
         <literal>busy</literal>,
         <literal>ring</literal>,
         <literal>failed</literal> or
         <literal>connected</literal>.
         A failed connection happens when the dialed telephone
         number does not exist (is unallocated).
   } );
# REFERENCE: schema:dialup
__( q{Hangup Status} );
# REFERENCE: schema:dialup
__( q{The status of the connection:
         <literal>no_answer</literal>,
         <literal>unallocated</literal> or
         <literal>normal</literal>.
         An unallocated telephone number is a number that does
         not exist.
   } );
# REFERENCE: schema:dialup
__( q{Cost} );
# REFERENCE: schema:dialup
__( q{The total cost of the dial up connection.} );
# REFERENCE: schema:dialup
__( q{Currency} );
# REFERENCE: schema:dialup
__( q{The currency in which the cost is expressed.} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Connection Time By Type By Period Dialup Report} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{This report lists the total connection time by period.} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{This parameter controls the time period over which the
     connection time is aggregated.
    } );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Connection Time By Type By $period Period} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Period} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Time} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{% Time for Type} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{% Total Time} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{Connections By Connect Status Dialup Report} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{This report shows the number of connections aggregated
   by connect status (ring, busy, connected or failed).
  } );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{Connections By Connect Status} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connections By Connection Time Dialup Report} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{This report shows the number of connections aggregated
        in configurable connection time range.
  } );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{This parameter controls the size of the connection time 
          ranges over which the connections are aggregated.
    } );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connections By Connection Time} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connection Time} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{Connections By Hangup Status Dialup Report} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{This report shows the number of connections aggregated
   by hangup status (no answer, normal, unallocated).
  } );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{Connections By Hangup Status} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-period
__( q{Connections By Period Dialup Report} );
# REFERENCE: report:dialup:connections-by-period
__( q{This report shows the number of connections aggregated
   in configurable time periods. It does only include succesful
   connections.
  } );
# REFERENCE: report:dialup:connections-by-period
__( q{This parameter controls the time period over which the
     connections are aggregated.
    } );
# REFERENCE: report:dialup:connections-by-period
__( q{Connections By $period Period} );
# REFERENCE: report:dialup:connections-by-period
__( q{Period} );
# REFERENCE: report:dialup:connections-by-period
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-period
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-type
__( q{Connections By Connection Type Dialup Report} );
# REFERENCE: report:dialup:connections-by-type
__( q{This report shows the number of connections aggregated
   by connection type (data or speech).
  } );
# REFERENCE: report:dialup:connections-by-type
__( q{Connections By Connection Type} );
# REFERENCE: report:dialup:connections-by-type
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-type
__( q{% Total} );
# REFERENCE: report:dialup:cost-by-period
__( q{Cost By Period Dialup Report} );
# REFERENCE: report:dialup:cost-by-period
__( q{This report lists the total cost by period.} );
# REFERENCE: report:dialup:cost-by-period
__( q{This parameter controls the time period over which the
     total cost is aggregated.
    } );
# REFERENCE: report:dialup:cost-by-period
__( q{Cost By $period Period} );
# REFERENCE: report:dialup:cost-by-period
__( q{Period} );
# REFERENCE: report:dialup:cost-by-period
__( q{Costs} );
# REFERENCE: report:dialup:cost-by-period
__( q{% Total for Currency} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{Cost By Telephone Number Dialup Report} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{This report lists the total cost for each telephone
        number which has been called to.} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{Cost By Telephone Number} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{Cost} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{% Total} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{Most Connections From Telephone Number Dialup Report} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{This report lists the telephone numbers from which the most
        connections were made.} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{This parameter controls the number of telephone numbers to
     display in the report.
    } );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{Most Connections from Telephone Numbers, Top $numbers_to_show} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{Connections} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{% Total} );
# REFERENCE: report:dialup:top-telephone-number
__( q{Most Connections To Telephone Number Dialup Report} );
# REFERENCE: report:dialup:top-telephone-number
__( q{This report lists the telephone numbers to which to most 
        connections were made.} );
# REFERENCE: report:dialup:top-telephone-number
__( q{This parameter controls the number of telephone numbers the
     display in the report.
    } );
# REFERENCE: report:dialup:top-telephone-number
__( q{Most Connections to Telephone Numbers, Top $numbers_to_show} );
# REFERENCE: report:dialup:top-telephone-number
__( q{Connections} );
# REFERENCE: report:dialup:top-telephone-number
__( q{% Total} );

==> lire_2.0.1.orig.tar.gz: lire-2.0.1/dialup/po/lire-dialup.pot.pl <==
# REFERENCE: dialup_default.xml
__( q{Connections} );
# REFERENCE: dialup_default.xml
__( q{Duration} );
# REFERENCE: dialup_default.xml
__( q{Telephone Number} );
# REFERENCE: dialup_default.xml
__( q{Costs} );
# REFERENCE: schema:dialup
__( q{DLF Schema for Dialup service} );
# REFERENCE: schema:dialup
__( q{The <type>dialup</type> DLF schema represents each connection attempt with one DLF record. } );
# REFERENCE: schema:dialup
__( q{Timestamp} );
# REFERENCE: schema:dialup
__( q{The time at which the dial up connection started.} );
# REFERENCE: schema:dialup
__( q{Local Number} );
# REFERENCE: schema:dialup
__( q{Telephone number of the local telephone.} );
# REFERENCE: schema:dialup
__( q{Remote Number} );
# REFERENCE: schema:dialup
__( q{Telephone number which is being called.} );
# REFERENCE: schema:dialup
__( q{connection_time} );
# REFERENCE: schema:dialup
__( q{The duration of the dial up connection.} );
# REFERENCE: schema:dialup
__( q{Direction} );
# REFERENCE: schema:dialup
__( q{Direction of the connection. <literal>Inbound</literal> connections are those in which is machine on which the log is recorded is called, while in <literal>outbound</literal> connections the machine makes the call. } );
# REFERENCE: schema:dialup
__( q{Connection Type} );
# REFERENCE: schema:dialup
__( q{The type of the connection: <literal>speech</literal> or <literal>data</literal>.} );
# REFERENCE: schema:dialup
__( q{Connect Status} );
# REFERENCE: schema:dialup
__( q{The status of the connection: <literal>busy</literal>, <literal>ring</literal>, <literal>failed</literal> or <literal>connected</literal>. A failed connection happens when the dialed telephone number does not exist (is unallocated). } );
# REFERENCE: schema:dialup
__( q{Hangup Status} );
# REFERENCE: schema:dialup
__( q{The status of the connection: <literal>no_answer</literal>, <literal>unallocated</literal> or <literal>normal</literal>. An unallocated telephone number is a number that does not exist. } );
# REFERENCE: schema:dialup
__( q{Cost} );
# REFERENCE: schema:dialup
__( q{The total cost of the dial up connection.} );
# REFERENCE: schema:dialup
__( q{Currency} );
# REFERENCE: schema:dialup
__( q{The currency in which the cost is expressed.} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Connection Time By Type By Period Dialup Report} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{This report lists the total connection time by period.} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{This parameter controls the time period over which the connection time is aggregated. } );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Connection Time By Type By $period Period} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Period} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{Time} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{% Time for Type} );
# REFERENCE: report:dialup:connection-time-by-period
__( q{% Total Time} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{Connections By Connect Status Dialup Report} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{This report shows the number of connections aggregated by connect status (ring, busy, connected or failed). } );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{Connections By Connect Status} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-connect-status
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connections By Connection Time Dialup Report} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{This report shows the number of connections aggregated in configurable connection time range. } );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{This parameter controls the size of the connection time ranges over which the connections are aggregated. } );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connections By Connection Time} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connection Time} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-connection-time
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{Connections By Hangup Status Dialup Report} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{This report shows the number of connections aggregated by hangup status (no answer, normal, unallocated). } );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{Connections By Hangup Status} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-hangup-status
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-period
__( q{Connections By Period Dialup Report} );
# REFERENCE: report:dialup:connections-by-period
__( q{This report shows the number of connections aggregated in configurable time periods. It does only include succesful connections. } );
# REFERENCE: report:dialup:connections-by-period
__( q{This parameter controls the time period over which the connections are aggregated. } );
# REFERENCE: report:dialup:connections-by-period
__( q{Connections By $period Period} );
# REFERENCE: report:dialup:connections-by-period
__( q{Period} );
# REFERENCE: report:dialup:connections-by-period
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-period
__( q{% Total} );
# REFERENCE: report:dialup:connections-by-type
__( q{Connections By Connection Type Dialup Report} );
# REFERENCE: report:dialup:connections-by-type
__( q{This report shows the number of connections aggregated by connection type (data or speech). } );
# REFERENCE: report:dialup:connections-by-type
__( q{Connections By Connection Type} );
# REFERENCE: report:dialup:connections-by-type
__( q{Connections} );
# REFERENCE: report:dialup:connections-by-type
__( q{% Total} );
# REFERENCE: report:dialup:cost-by-period
__( q{Cost By Period Dialup Report} );
# REFERENCE: report:dialup:cost-by-period
__( q{This report lists the total cost by period.} );
# REFERENCE: report:dialup:cost-by-period
__( q{This parameter controls the time period over which the total cost is aggregated. } );
# REFERENCE: report:dialup:cost-by-period
__( q{Cost By $period Period} );
# REFERENCE: report:dialup:cost-by-period
__( q{Period} );
# REFERENCE: report:dialup:cost-by-period
__( q{Costs} );
# REFERENCE: report:dialup:cost-by-period
__( q{% Total for Currency} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{Cost By Telephone Number Dialup Report} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{This report lists the total cost for each telephone number which has been called to.} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{Cost By Telephone Number} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{Cost} );
# REFERENCE: report:dialup:cost-by-telephone-number
__( q{% Total} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{Most Connections From Telephone Number Dialup Report} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{This report lists the telephone numbers from which the most connections were made.} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{This parameter controls the number of telephone numbers to display in the report. } );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{Most Connections from Telephone Numbers, Top $numbers_to_show} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{Connections} );
# REFERENCE: report:dialup:top-telephone-number-from
__( q{% Total} );
# REFERENCE: report:dialup:top-telephone-number
__( q{Most Connections To Telephone Number Dialup Report} );
# REFERENCE: report:dialup:top-telephone-number
__( q{This report lists the telephone numbers to which to most connections were made.} );
# REFERENCE: report:dialup:top-telephone-number
__( q{This parameter controls the number of telephone numbers the display in the report. } );
# REFERENCE: report:dialup:top-telephone-number
__( q{Most Connections to Telephone Numbers, Top $numbers_to_show} );
# REFERENCE: report:dialup:top-telephone-number
__( q{Connections} );
# REFERENCE: report:dialup:top-telephone-number
__( q{% Total} );
